searchData={"items":[{"type":"module","title":"Jaqex","doc":"Documentation for `Jaqex`.","ref":"Jaqex.html"},{"type":"function","title":"Jaqex.filter/3","doc":"Filter the given JSON string with the given j(a)q code.","ref":"Jaqex.html#filter/3"},{"type":"function","title":"Jaqex.filter!/3","doc":"Filter the given JSON string with the given j(a)q code, raising on errors.","ref":"Jaqex.html#filter!/3"},{"type":"function","title":"Jaqex.filter_file/3","doc":"Filter the JSON in the given file with the given j(a)q code.","ref":"Jaqex.html#filter_file/3"},{"type":"function","title":"Jaqex.filter_file!/3","doc":"Filter the JSON in the given file with the given j(a)q code, raising on errors.","ref":"Jaqex.html#filter_file!/3"},{"type":"extras","title":"Jaqex","doc":"# Jaqex\nElixir wrapper for [jaq](https://github.com/01mf02/jaq), a [jq](https://jqlang.github.io/jq/)\nclone focused on correctness, speed, and simplicity implemented in Rust.\n\nUnlike other jq wrappers, this doesn't require jq to be installed/available in `$PATH`:\nJaqex uses [rustler](https://hexdocs.pm/rustler/) to implement the NIFs to jaq.\nAnd because Jaqex uses jaq, certain jq features like SQL-style operators aren't available.\nPlease refer to [jaq's README \"differences between jq and jaq\"][diff]\nfor more information. Despite such differences, jaq should still be useful in most\nscenarios, especially in the succintness in filtering/transforming JSON.\n\nThe following demonstrates the difference between using Elixir/Jason and Jaqex. Assuming\nwe have transform the following JSON doc from this:\n\n```json\n{\n    \"ticker\": \"AAPL\",\n    \"adjusted\": true,\n    \"prices\": [\n        {\"o\": 229.52, \"h\": 229.65, \"l\": 223.74, \"c\": 226.21, \"d\": \"2024-10-01\"},\n        {\"o\": 225.89, \"h\": 227.37, \"l\": 223.02, \"c\": 226.78, \"d\": \"2024-10-02\"}\n    ]\n}\n```\n\nTo this:\n\n```elixir\n[\n    %{\n        \"open\" => 229.52, \"high\": 229.65, \"low\" => 223.74, \"close\" => 226.21,\n        \"date\" => \"2024-10-01\", \"ticker\" => \"AAPL\", \"adjusted\": true\n    },\n    %{\n        \"open\" => 225.89, \"high\": 227.37, \"low\" => 223.02, \"close\" => 226.78,\n        \"date\" => \"2024-10-02\", \"ticker\" => \"AAPL\", \"adjusted\": true\n   },\n]\n```\n\nThe following shows how it's done using Elixir and Jason:\n\n\n```elixir\ndoc = Jason.decode!(json_string)    # assuming the contents are in json_string\nrenames = %{\"o\" => \"open\", \"h\" => \"high\", \"l\" => \"low\", \"c\" => \"close\", \"d\" => \"date\"}\nadditions = Map.take(doc, [\"ticker\", \"adjusted\"])\n\nresult =\n    doc[\"prices\"]\n    |> Stream.map(fn m ->\n        renames |> Stream.map(fn {original, new_name} -> {new_name, m[original]} end)\n    end)\n    |> Stream.map(&Map.new/1)\n    |> Enum.map(&Map.merge(&1, additions))\n```\n\nComparing that with using Jaqex:\n\n```elixir\nresult = Jaqex.filter!(\n    json_string,\n    \"[. as $root | .prices[] |\n        {open: .o, high: .h, low: .l, close: .c,\n         date: .d, ticker: $root.ticker, adjusted: $root.adjusted}\n    ]\"\n)\n```\n\nJaq/jq filters make transformations as such straightforward.\n\n[diff]: https://github.com/01mf02/jaq/blob/main/README.md#differences-between-jq-and-jaq","ref":"readme.html"},{"type":"extras","title":"Installation - Jaqex","doc":"Add `jaqex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:jaqex, \"~> 0.1.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Copyright and License - Jaqex","doc":"Copyright© 2024, Shaolang Ai\n\nDistributed under the MIT License","ref":"readme.html#copyright-and-license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}